// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Stock Market Brick Code File
// ============================================================
// Table of Contents
// 1. Brick Data
// 2. Trigger Data
// 3. Functions
// 4. Package
// ============================================================

// ============================================================
// Section 1 : Brick Data
// ============================================================
datablock fxDTSBrickData(CityRPSMBrickData : brick2x4FData)
{
	category = "IbanMods";
	subCategory = "CityRPG Infoblocks";
	
	uiName = "Stock Market Brick";
	
	CityRPBrickType = 2;
	CityRPBrickAdmin = true;
	
	triggerDatablock = CityRPInputTriggerData;
	triggerSize = "2 4 1";
	trigger = 0;
};

// ============================================================
// Section 2 : Trigger Data
// ============================================================
function CityRPSMData::parseData(%this, %brick, %client, %triggerStatus, %text)
{
	if(%triggerStatus !$= "")
	{
		if(%triggerStatus == true && %client.stage $= "")
		{
			messageClient(%client, '', "\c6Welcome to the Blockland Stock Exchange. How can I help?");
			
			messageClient(%client, '', "\c31 \c6- Withdraw money.");
						
			%client.stage = 0;
		}
		
		if(%triggerStatus == false && %client.stage !$= "")
		{
			messageClient(%client, '', "\c6Thanks, come again.");
			
			%client.stage = "";
		}
		
		return;
	}
	
	%input = strLwr(%text);
	
	if(mFloor(%client.stage) == 0)
	{
		if(strReplace(%input, "1", "") !$= %input || strReplace(%input, "one", "") !$= %input)
		{
			%client.stage = 1.1;
			
			messageClient(%client, '', "\c6Please enter the amount of money you wish to withdraw.");
			
			return;
		}
		
		if(strReplace(%input, "2", "") !$= %input || strReplace(%input, "two", "") !$= %input)
		{
			%client.stage = 1.2;
			
			messageClient(%client, '', "\c6Please enter the amount of money you wish to deposit.");
			
			return;
		}
		
		if(strReplace(%input, "3", "") !$= %input || strReplace(%input, "three", "") !$= %input)
		{
			%client.stage = 1.2;
			
			serverCmdMessageSent(%client, CityRPData.getData(%client.bl_id).valueMoney);
			
			return;
		}
		if(strReplace(%input, "4", "") !$= %input || strReplace(%input, "four", "") !$= %input)
		{
			%client.stage = 1.3;
			
			serverCmdMessageSent(%client, "");
			
			return;
		}
		
		messageClient(%client, '', "\c3" @ %text SPC "\c6is not a valid option!");
		
		return;
	}
	
	if(mFloor(%client.stage) == 1)
	{
		if(%client.stage == 1.1)
		{
			if(mFloor(%input) < 1)
			{
				messageClient(%client, '', "\c6Please enter a valid amount of money to withdraw.");
				
				return;
			}
		}
		
		return;
	}
}

// ============================================================
// Section 3 : Functions
// ============================================================
function CityRP_BuildStockMarket()
{
	if(!isObject(CityRPSMData))
	{
		echo("SM :: Building Database");
		CityRPSMData.addValue("ticker", "");
		CityRPSMData.addValue("value", 100);
		
		for(%a = 1; %a < $CityRP::SM::totalStocks; %a++)
		{
			echo("SM :: Building Ticker" SPC %a);
			CityRPSMData.addData(%a);
			if(%a == 1)
			{
				// Easter Egg
				CityRPSMData.getData(%a).valueTicker = "APPL";
			}
			else
			{
				while(!%stringPass)
				{
					if(%tickerLength) { echo("SM :: Name failed! Restarting.."); }
					
					%tickerLength = getRandom(2, 5);
					%tickerName = "";
					%stringPass = true;
					
					for(%b = 1; %b <= %tickerLength; %b++)
					{
						%tickerName += getSubStr("ABCDEFGHIJKLMNOPQRSTUVWXYZ", getRandom(0, 25), 0);
					}
					
					for(%c = 1; %c <= CityRPData.dataCount; %c++)
					{
						if(CityRPSMData.getData(%a).valueTicker $= CityRPSMData.getData(%c).valueTicker && %a != %c)
						{
							%stringPass = true;
						}
					}
				}
				%stringPass = false;
				
				CityRPSMData.getData(%a).valueTicker = %tickerName;
				CityRPSMData.getData(%a).valueValue = mFloor(getRandom(CityRPSMData.getData(%a).valueValue / 2, CityRPSMData.getData(%a).valueValue));
			}
			
			echo("SM ::" SPC CityRPSMData.getData(%a).valueTicker SPC "(" @ CityRPSMData.getData(%a).valueValue @ ")" SPC "added.");
		}
	}
}

// ============================================================
// Section 4 : Package
// ============================================================
package CityRP_StockMarket
{
	function CityRP_BootUp()
	{
		parent::CityRP_BootUp();
		
		if(!isObject(CityRPSMData))
		{
			new scriptObject(CityRPSMData)
			{
				class = Sassy;
				dataFile = "config/server/IbanMod/CityRPG/StockMarket.dat";
			};
			
			if(!CityRPSMData.loadedSaveFile)
			{
				CityRP_BuildStockMarket();
			}
		}
	}
};
activatePackage(CityRP_StockMarket);